
.. image:: https://github.com/RAMP-project/RAMP/blob/master/docs/figures/RAMP_logo_basic.png?raw=true
   :width: 300

User Guide:

.. toctree::
   :maxdepth: 2

   intro
   algorithm
   examples
   api_references


